simsopt package
===============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   simsopt._core
   simsopt.configs
   simsopt.field
   simsopt.geo
   simsopt.mhd
   simsopt.objectives
   simsopt.solve
   simsopt.util
   simsoptpp

Module contents
---------------

.. automodule:: simsopt
   :members:
   :undoc-members:
   :show-inheritance:
